@@ -9,7 +9,7 @@
 #include "secretagent.h"
 #include "passworddialog.h"
 
-#include "debug.h"
+#include "plasma_nm_kded.h"
 
 #include "configuration.h"
 
@@ -35,7 +35,7 @@
 #include <KWindowSystem>
 
 SecretAgent::SecretAgent(QObject *parent)
-    : NetworkManager::SecretAgent("org.kde.plasma.networkmanagement", NetworkManager::SecretAgent::Capability::VpnHints, parent)
+    : NetworkManager::SecretAgent(QStringLiteral("org.kde.plasma.networkmanagement"), NetworkManager::SecretAgent::Capability::VpnHints, parent)
     , m_openWalletFailed(false)
     , m_wallet(nullptr)
     , m_dialog(nullptr)
@@ -46,9 +46,7 @@ SecretAgent::SecretAgent(QObject *parent)
     importSecretsFromPlainTextFiles();
 }
 
-SecretAgent::~SecretAgent()
-{
-}
+SecretAgent::~SecretAgent() = default;
 
 NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection,
                                         const QDBusObjectPath &connection_path,
@@ -56,16 +54,17 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection,
                                         const QStringList &hints,
                                         uint flags)
 {
-    qCDebug(PLASMA_NM) << Q_FUNC_INFO;
-    qCDebug(PLASMA_NM) << "Path:" << connection_path.path();
-    qCDebug(PLASMA_NM) << "Setting name:" << setting_name;
-    qCDebug(PLASMA_NM) << "Hints:" << hints;
-    qCDebug(PLASMA_NM) << "Flags:" << flags;
+    qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO;
+    qCDebug(PLASMA_NM_KDED_LOG) << "Path:" << connection_path.path();
+    qCDebug(PLASMA_NM_KDED_LOG) << "Setting name:" << setting_name;
+    qCDebug(PLASMA_NM_KDED_LOG) << "Hints:" << hints;
+    qCDebug(PLASMA_NM_KDED_LOG) << "Flags:" << flags;
 
     const QString callId = connection_path.path() % setting_name;
-    for (const SecretsRequest &request : m_calls) {
+    for (const SecretsRequest &request : std::as_const(m_calls)) {
         if (request == callId) {
-            qCWarning(PLASMA_NM) << "GetSecrets was called again! This should not happen, cancelling first call" << connection_path.path() << setting_name;
+            qCWarning(PLASMA_NM_KDED_LOG) << "GetSecrets was called again! This should not happen, cancelling first call" << connection_path.path()
+                                          << setting_name;
             CancelGetSecrets(connection_path, setting_name);
             break;
         }
@@ -84,14 +83,14 @@ NMVariantMapMap SecretAgent::GetSecrets(const NMVariantMapMap &connection,
 
     processNext();
 
-    return NMVariantMapMap();
+    return {};
 }
 
 void SecretAgent::SaveSecrets(const NMVariantMapMap &connection, const QDBusObjectPath &connection_path)
 {
-    qCDebug(PLASMA_NM) << Q_FUNC_INFO;
-    qCDebug(PLASMA_NM) << "Path:" << connection_path.path();
-    // qCDebug(PLASMA_NM) << "Setting:" << connection;
+    qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO;
+    qCDebug(PLASMA_NM_KDED_LOG) << "Path:" << connection_path.path();
+    // qCDebug(PLASMA_NM_KDED_LOG) << "Setting:" << connection;
 
     setDelayedReply(true);
     SecretsRequest::Type type;
@@ -111,9 +110,9 @@ void SecretAgent::SaveSecrets(const NMVariantMapMap &connection, const QDBusObje
 
 void SecretAgent::DeleteSecrets(const NMVariantMapMap &connection, const QDBusObjectPath &connection_path)
 {
-    qCDebug(PLASMA_NM) << Q_FUNC_INFO;
-    qCDebug(PLASMA_NM) << "Path:" << connection_path.path();
-    // qCDebug(PLASMA_NM) << "Setting:" << connection;
+    qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO;
+    qCDebug(PLASMA_NM_KDED_LOG) << "Path:" << connection_path.path();
+    // qCDebug(PLASMA_NM_KDED_LOG) << "Setting:" << connection;
 
     setDelayedReply(true);
     SecretsRequest request(SecretsRequest::DeleteSecrets);
@@ -127,9 +126,9 @@ void SecretAgent::DeleteSecrets(const NMVariantMapMap &connection, const QDBusOb
 
 void SecretAgent::CancelGetSecrets(const QDBusObjectPath &connection_path, const QString &setting_name)
 {
-    qCDebug(PLASMA_NM) << Q_FUNC_INFO;
-    qCDebug(PLASMA_NM) << "Path:" << connection_path.path();
-    qCDebug(PLASMA_NM) << "Setting name:" << setting_name;
+    qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO;
+    qCDebug(PLASMA_NM_KDED_LOG) << "Path:" << connection_path.path();
+    qCDebug(PLASMA_NM_KDED_LOG) << "Setting name:" << setting_name;
 
     QString callId = connection_path.path() % setting_name;
     for (int i = 0; i < m_calls.size(); ++i) {
@@ -139,7 +138,7 @@ void SecretAgent::CancelGetSecrets(const QDBusObjectPath &connection_path, const
                 m_dialog = nullptr;
             }
             delete request.dialog;
-            sendError(SecretAgent::AgentCanceled, QLatin1String("Agent canceled the password dialog"), request.message);
+            sendError(SecretAgent::AgentCanceled, QStringLiteral("Agent canceled the password dialog"), request.message);
             m_calls.removeAt(i);
             break;
         }
@@ -155,11 +154,11 @@ void SecretAgent::dialogAccepted()
         if (request.type == SecretsRequest::GetSecrets && request.dialog == m_dialog) {
             NMStringMap tmpOpenconnectSecrets;
             NMVariantMapMap connection = request.dialog->secrets();
-            if (connection.contains(QLatin1String("vpn"))) {
-                if (connection.value(QStringLiteral("vpn")).contains(QLatin1String("tmp-secrets"))) {
-                    QVariantMap vpnSetting = connection.value(QLatin1String("vpn"));
-                    tmpOpenconnectSecrets = qdbus_cast<NMStringMap>(vpnSetting.take(QLatin1String("tmp-secrets")));
-                    connection.insert(QLatin1String("vpn"), vpnSetting);
+            if (connection.contains(QStringLiteral("vpn"))) {
+                if (connection.value(QStringLiteral("vpn")).contains(QStringLiteral("tmp-secrets"))) {
+                    QVariantMap vpnSetting = connection.value(QStringLiteral("vpn"));
+                    tmpOpenconnectSecrets = qdbus_cast<NMStringMap>(vpnSetting.take(QStringLiteral("tmp-secrets")));
+                    connection.insert(QStringLiteral("vpn"), vpnSetting);
                 }
             }
 
@@ -222,13 +221,13 @@ void SecretAgent::dialogAccepted()
                     NMStringMap secrets = vpnSetting->secrets();
 
                     // Load secrets from auth dialog which are returned back to NM
-                    if (connection.value(QLatin1String("vpn")).contains(QLatin1String("secrets"))) {
-                        secrets.unite(qdbus_cast<NMStringMap>(connection.value(QLatin1String("vpn")).value(QLatin1String("secrets"))));
+                    if (connection.value(QStringLiteral("vpn")).contains(QStringLiteral("secrets"))) {
+                        secrets.unite(qdbus_cast<NMStringMap>(connection.value(QStringLiteral("vpn")).value(QStringLiteral("secrets"))));
                     }
 
                     // Load temporary secrets from auth dialog which are not returned to NM
                     for (const QString &key : tmpOpenconnectSecrets.keys()) {
-                        if (secrets.contains(QLatin1String("save_passwords")) && secrets.value(QLatin1String("save_passwords")) == QLatin1String("yes")) {
+                        if (secrets.contains(QStringLiteral("save_passwords")) && secrets.value(QStringLiteral("save_passwords")) == QLatin1String("yes")) {
                             data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::AgentOwned));
                         } else {
                             data.insert(key + QLatin1String("-flags"), QString::number(NetworkManager::Setting::NotSaved));
@@ -264,7 +263,7 @@ void SecretAgent::dialogRejected()
     for (int i = 0; i < m_calls.size(); ++i) {
         SecretsRequest request = m_calls[i];
         if (request.type == SecretsRequest::GetSecrets && request.dialog == m_dialog) {
-            sendError(SecretAgent::UserCanceled, QLatin1String("User canceled the password dialog"), request.message);
+            sendError(SecretAgent::UserCanceled, QStringLiteral("User canceled the password dialog"), request.message);
             m_calls.removeAt(i);
             break;
         }
@@ -360,16 +359,16 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
         NetworkManager::VpnSetting::Ptr vpnSetting = connectionSettings->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
         if (vpnSetting->serviceType() == QLatin1String("org.freedesktop.NetworkManager.ssh") && vpnSetting->data()["auth-type"] == QLatin1String("ssh-agent")) {
             QString authSock = qgetenv("SSH_AUTH_SOCK");
-            qCDebug(PLASMA_NM) << Q_FUNC_INFO << "Sending SSH auth socket" << authSock;
+            qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO << "Sending SSH auth socket" << authSock;
 
             if (authSock.isEmpty()) {
-                sendError(SecretAgent::NoSecrets, QLatin1String("SSH_AUTH_SOCK not present"), request.message);
+                sendError(SecretAgent::NoSecrets, QStringLiteral("SSH_AUTH_SOCK not present"), request.message);
             } else {
                 NMStringMap secrets;
-                secrets.insert(QLatin1String("ssh-auth-sock"), authSock);
+                secrets.insert(QStringLiteral("ssh-auth-sock"), authSock);
 
                 QVariantMap secretData;
-                secretData.insert(QLatin1String("secrets"), QVariant::fromValue<NMStringMap>(secrets));
+                secretData.insert(QStringLiteral("secrets"), QVariant::fromValue<NMStringMap>(secrets));
                 request.connection[request.setting_name] = secretData;
                 sendSecrets(request.connection, request.message);
             }
@@ -380,12 +379,12 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
     NMStringMap secretsMap;
     if (!requestNew && useWallet()) {
         if (m_wallet->isOpen()) {
-            if (m_wallet->hasFolder("Network Management") && m_wallet->setFolder("Network Management")) {
+            if (m_wallet->hasFolder(QStringLiteral("Network Management")) && m_wallet->setFolder(QStringLiteral("Network Management"))) {
                 QString key = QLatin1Char('{') % connectionSettings->uuid() % QLatin1Char('}') % QLatin1Char(';') % request.setting_name;
                 m_wallet->readMap(key, secretsMap);
             }
         } else {
-            qCDebug(PLASMA_NM) << Q_FUNC_INFO << "Waiting for the wallet to open";
+            qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO << "Waiting for the wallet to open";
             return false;
         }
     }
@@ -401,7 +400,7 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
     }
 
     if (!Configuration::self().showPasswordDialog()) {
-        sendError(SecretAgent::NoSecrets, "Cannot authenticate", request.message);
+        sendError(SecretAgent::NoSecrets, QStringLiteral("Cannot authenticate"), request.message);
         emit secretsError(request.connection_path.path(),
                           i18n("Authentication to %1 failed. Wrong password?", request.connection.value("connection").value("id").toString()));
         return true;
@@ -415,10 +414,10 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
             // Insert an empty secrets map as it was before I fixed it in NetworkManagerQt to make sure NM will ask again
             // with flags we need
             QVariantMap secretsMap;
-            secretsMap.insert(QLatin1String("secrets"), QVariant::fromValue<NMStringMap>(NMStringMap()));
-            result.insert("wireguard", secretsMap);
+            secretsMap.insert(QStringLiteral("secrets"), QVariant::fromValue<NMStringMap>(NMStringMap()));
+            result.insert(QStringLiteral("wireguard"), secretsMap);
         } else {
-            result.insert("wireguard", wireGuardSetting->secretsToMap());
+            result.insert(QStringLiteral("wireguard"), wireGuardSetting->secretsToMap());
         }
         sendSecrets(result, request.message);
         return true;
@@ -451,10 +450,10 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
             // Insert an empty secrets map as it was before I fixed it in NetworkManagerQt to make sure NM will ask again
             // with flags we need
             QVariantMap secretsMap;
-            secretsMap.insert(QLatin1String("secrets"), QVariant::fromValue<NMStringMap>(NMStringMap()));
-            result.insert("vpn", secretsMap);
+            secretsMap.insert(QStringLiteral("secrets"), QVariant::fromValue<NMStringMap>(NMStringMap()));
+            result.insert(QStringLiteral("vpn"), secretsMap);
         } else {
-            result.insert("vpn", vpnSetting->secretsToMap());
+            result.insert(QStringLiteral("vpn"), vpnSetting->secretsToMap());
         }
         sendSecrets(result, request.message);
         return true;
@@ -464,7 +463,7 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
         sendSecrets(result, request.message);
         return true;
     } else {
-        sendError(SecretAgent::InternalError, QLatin1String("Plasma-nm did not know how to handle the request"), request.message);
+        sendError(SecretAgent::InternalError, QStringLiteral("Plasma-nm did not know how to handle the request"), request.message);
         return true;
     }
 }
@@ -475,11 +474,11 @@ bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
         if (m_wallet->isOpen()) {
             NetworkManager::ConnectionSettings connectionSettings(request.connection);
 
-            if (!m_wallet->hasFolder("Network Management")) {
-                m_wallet->createFolder("Network Management");
+            if (!m_wallet->hasFolder(QStringLiteral("Network Management"))) {
+                m_wallet->createFolder(QStringLiteral("Network Management"));
             }
 
-            if (m_wallet->setFolder("Network Management")) {
+            if (m_wallet->setFolder(QStringLiteral("Network Management"))) {
                 for (const NetworkManager::Setting::Ptr &setting : connectionSettings.settings()) {
                     NMStringMap secretsMap = setting->secretsToStringMap();
 
@@ -489,11 +488,11 @@ bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
                     }
                 }
             } else if (!request.saveSecretsWithoutReply) {
-                sendError(SecretAgent::InternalError, QLatin1String("Could not store secrets in the wallet."), request.message);
+                sendError(SecretAgent::InternalError, QStringLiteral("Could not store secrets in the wallet."), request.message);
                 return true;
             }
         } else {
-            qCDebug(PLASMA_NM) << Q_FUNC_INFO << "Waiting for the wallet to open";
+            qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO << "Waiting for the wallet to open";
             return false;
         }
     }
@@ -501,7 +500,7 @@ bool SecretAgent::processSaveSecrets(SecretsRequest &request) const
     if (!request.saveSecretsWithoutReply) {
         QDBusMessage reply = request.message.createReply();
         if (!QDBusConnection::systemBus().send(reply)) {
-            qCWarning(PLASMA_NM) << "Failed put save secrets reply into the queue";
+            qCWarning(PLASMA_NM_KDED_LOG) << "Failed put save secrets reply into the queue";
         }
     }
 
@@ -512,7 +511,7 @@ bool SecretAgent::processDeleteSecrets(SecretsRequest &request) const
 {
     if (useWallet()) {
         if (m_wallet->isOpen()) {
-            if (m_wallet->hasFolder("Network Management") && m_wallet->setFolder("Network Management")) {
+            if (m_wallet->hasFolder(QStringLiteral("Network Management")) && m_wallet->setFolder(QStringLiteral("Network Management"))) {
                 NetworkManager::ConnectionSettings connectionSettings(request.connection);
                 for (const NetworkManager::Setting::Ptr &setting : connectionSettings.settings()) {
                     QString entryName = QLatin1Char('{') % connectionSettings.uuid() % QLatin1Char('}') % QLatin1Char(';') % setting->name();
@@ -524,14 +523,14 @@ bool SecretAgent::processDeleteSecrets(SecretsRequest &request) const
                 }
             }
         } else {
-            qCDebug(PLASMA_NM) << Q_FUNC_INFO << "Waiting for the wallet to open";
+            qCDebug(PLASMA_NM_KDED_LOG) << Q_FUNC_INFO << "Waiting for the wallet to open";
             return false;
         }
     }
 
     QDBusMessage reply = request.message.createReply();
     if (!QDBusConnection::systemBus().send(reply)) {
-        qCWarning(PLASMA_NM) << "Failed put delete secrets reply into the queue";
+        qCWarning(PLASMA_NM_KDED_LOG) << "Failed put delete secrets reply into the queue";
     }
 
     return true;
@@ -557,7 +556,7 @@ bool SecretAgent::useWallet() const
             connect(m_wallet, &KWallet::Wallet::walletClosed, this, &SecretAgent::walletClosed);
             return true;
         } else {
-            qCWarning(PLASMA_NM) << "Error opening kwallet.";
+            qCWarning(PLASMA_NM_KDED_LOG) << "Error opening kwallet.";
         }
     } else if (m_wallet) {
         m_wallet->deleteLater();
@@ -584,19 +583,19 @@ void SecretAgent::sendSecrets(const NMVariantMapMap &secrets, const QDBusMessage
     QDBusMessage reply;
     reply = message.createReply(QVariant::fromValue(secrets));
     if (!QDBusConnection::systemBus().send(reply)) {
-        qCWarning(PLASMA_NM) << "Failed put the secret into the queue";
+        qCWarning(PLASMA_NM_KDED_LOG) << "Failed put the secret into the queue";
     }
 }
 
 void SecretAgent::importSecretsFromPlainTextFiles()
 {
-    KConfig config(QLatin1String("plasma-networkmanagement"), KConfig::SimpleConfig);
+    KConfig config(QStringLiteral("plasma-networkmanagement"), KConfig::SimpleConfig);
 
     // No action is required when the list of secrets is empty
     if (!config.groupList().isEmpty()) {
         for (const QString &groupName : config.groupList()) {
-            QString loadedUuid = groupName.split(';').first().remove('{').remove('}');
-            QString loadedSettingType = groupName.split(';').last();
+            QString loadedUuid = groupName.split(QLatin1Char(';')).first().remove('{').remove('}');
+            QString loadedSettingType = groupName.split(QLatin1Char(';')).last();
             NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(loadedUuid);
             if (connection) {
                 NetworkManager::Setting::SecretFlags secretFlags =
