@@ -5,7 +5,7 @@
 */
 
 #include "wificonnectionwidget.h"
-#include "debug.h"
+#include "plasma_nm_editor.h"
 #include "ui_wificonnectionwidget.h"
 
 #include <KLocalizedString>
@@ -110,7 +110,7 @@ QVariantMap WifiConnectionWidget::setting() const
 void WifiConnectionWidget::generateRandomClonedMac()
 {
     QByteArray mac;
-    auto *generator = QRandomGenerator::global();
+    auto generator = QRandomGenerator::global();
     mac.resize(6);
     for (int i = 0; i < 6; i++) {
         const int random = generator->bounded(255);
@@ -173,7 +173,7 @@ void WifiConnectionWidget::fillChannels(NetworkManager::WirelessSetting::Frequen
     } else if (band == NetworkManager::WirelessSetting::Bg) {
         channels = NetworkManager::getBFreqs();
     } else {
-        qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unhandled band number" << band;
+        qCWarning(PLASMA_NM_EDITOR_LOG) << Q_FUNC_INFO << "Unhandled band number" << band;
         return;
     }
 
