@@ -4,7 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "wireguardpeerwidget.h"
-#include "debug.h"
+#include "plasma_nm_editor.h"
 #include "simpleiplistvalidator.h"
 #include "simpleipv4addressvalidator.h"
 #include "ui_wireguardpeerwidget.h"
@@ -55,9 +55,7 @@ public:
     bool presharedKeyValid = true;
 };
 
-WireGuardPeerWidget::Private::~Private()
-{
-}
+WireGuardPeerWidget::Private::~Private() = default;
 
 WireGuardPeerWidget::WireGuardPeerWidget(const QVariantMap &peerData, QWidget *parent, Qt::WindowFlags f)
     : QDialog(parent, f)
@@ -88,7 +86,7 @@ WireGuardPeerWidget::WireGuardPeerWidget(const QVariantMap &peerData, QWidget *p
     d->ui.presharedKeyLineEdit->setPasswordNotSavedEnabled(false);
 
     // Create validator for endpoint port
-    QIntValidator *portValidator = new QIntValidator(this);
+    auto portValidator = new QIntValidator(this);
     portValidator->setBottom(0);
     portValidator->setTop(65535);
     d->ui.endpointPortLineEdit->setValidator(portValidator);
@@ -158,7 +156,7 @@ void WireGuardPeerWidget::checkAllowedIpsValid()
     int pos = 0;
     QLineEdit *widget = d->ui.allowedIPsLineEdit;
     QString ipString = widget->displayText();
-    QStringList rawIPList = ipString.split(',');
+    QStringList rawIPList = ipString.split(QLatin1Char(','));
     QStringList ipList;
 
     bool valid = QValidator::Acceptable == allowedIPsValidator.validate(ipString, pos);
@@ -209,7 +207,6 @@ void WireGuardPeerWidget::checkEndpointValid()
     QString addressString = addressWidget->displayText();
     QString portString = portWidget->displayText();
 
-    QUrl temp;
     WireGuardPeerWidget::EndPointValid valid = isEndpointValid(addressString, portString);
 
     setBackground(addressWidget, WireGuardPeerWidget::BothValid == valid || WireGuardPeerWidget::AddressValid == valid);
