@@ -20,7 +20,6 @@ bool signalCompare(const NetworkManager::AccessPoint::Ptr &one, const NetworkMan
 
 BssidComboBox::BssidComboBox(QWidget *parent)
     : QComboBox(parent)
-    , m_dirty(false)
 {
     setEditable(true);
     setInsertPolicy(QComboBox::NoInsert);
@@ -37,7 +36,7 @@ QString BssidComboBox::bssid() const
     else
         result = currentText();
 
-    // qCDebug(PLASMA_NM) << "Result:" << currentIndex() << result;
+    // qCDebug(PLASMA_NM_EDITOR_LOG) << "Result:" << currentIndex() << result;
 
     return result;
 }
@@ -68,7 +67,7 @@ void BssidComboBox::init(const QString &bssid, const QString &ssid)
 {
     m_initialBssid = bssid;
 
-    // qCDebug(PLASMA_NM) << "Initial ssid:" << m_initialBssid;
+    // qCDebug(PLASMA_NM_EDITOR_LOG) << "Initial ssid:" << m_initialBssid;
 
     QList<NetworkManager::AccessPoint::Ptr> aps;
 
@@ -83,7 +82,6 @@ void BssidComboBox::init(const QString &bssid, const QString &ssid)
 
             for (const NetworkManager::AccessPoint::Ptr &newAp : wifiNetwork->accessPoints()) {
                 bool found = false;
-                ;
                 for (const NetworkManager::AccessPoint::Ptr &existingAp : aps) {
                     if (newAp->hardwareAddress() == existingAp->hardwareAddress()) {
                         if (newAp->signalStrength() > existingAp->signalStrength()) {
