@@ -17,7 +17,7 @@ class Q_DECL_EXPORT HwAddrComboBox : public QComboBox
 public:
     explicit HwAddrComboBox(QWidget *parent = nullptr);
 
-    void init(const NetworkManager::Device::Type &deviceType, const QString &address);
+    void init(NetworkManager::Device::Type deviceType, const QString &address);
 
     bool isValid() const;
     QString hwAddress() const;
@@ -33,7 +33,7 @@ private:
     void addAddressToCombo(const NetworkManager::Device::Ptr &device);
     QVariant hwAddressFromDevice(const NetworkManager::Device::Ptr &device);
     QString m_initialAddress;
-    bool m_dirty;
+    bool m_dirty = false;
 };
 
 #endif // PLASMA_NM_HWADDRCOMBOBOX_H
