@@ -22,7 +22,7 @@ public:
     Private()
         : model(0, 4)
     {
-        QStandardItem *headerItem = new QStandardItem(i18nc("Header text for IPv4 address", "Address"));
+        auto headerItem = new QStandardItem(i18nc("Header text for IPv4 address", "Address"));
         model.setHorizontalHeaderItem(0, headerItem);
         headerItem = new QStandardItem(i18nc("Header text for IPv4 netmask", "Netmask"));
         model.setHorizontalHeaderItem(1, headerItem);
@@ -43,8 +43,8 @@ IpV4RoutesWidget::IpV4RoutesWidget(QWidget *parent)
     d->ui.tableViewAddresses->setModel(&d->model);
     d->ui.tableViewAddresses->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
 
-    IpV4Delegate *ipDelegate = new IpV4Delegate(this);
-    IntDelegate *metricDelegate = new IntDelegate(this);
+    auto ipDelegate = new IpV4Delegate(this);
+    auto metricDelegate = new IntDelegate(this);
     d->ui.tableViewAddresses->setItemDelegateForColumn(0, ipDelegate);
     d->ui.tableViewAddresses->setItemDelegateForColumn(1, ipDelegate);
     d->ui.tableViewAddresses->setItemDelegateForColumn(2, ipDelegate);
@@ -167,7 +167,7 @@ void IpV4RoutesWidget::removeRoute()
 
 void IpV4RoutesWidget::selectionChanged(const QItemSelection &selected)
 {
-    // qCDebug(PLASMA_NM) << "selectionChanged";
+    // qCDebug(PLASMA_NM_EDITOR_LOG) << "selectionChanged";
     d->ui.pushButtonRemove->setEnabled(!selected.isEmpty());
 }
 
