@@ -1,21 +1,7 @@
 /*
-    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef PLASMA_NM_HANDLER_H
@@ -25,17 +11,16 @@
 #include <QTimer>
 
 #include <NetworkManagerQt/Connection>
-#include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/ConnectionSettings>
+#include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Utils>
 #if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/GenericTypes>
 #endif
 
-
 class Q_DECL_EXPORT Handler : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     enum HandlerAction {
@@ -49,12 +34,16 @@ public:
         CreateHotspot,
     };
 
-    explicit Handler(QObject* parent = nullptr);
+    explicit Handler(QObject *parent = nullptr);
     ~Handler() override;
 
     Q_PROPERTY(bool hotspotSupported READ hotspotSupported NOTIFY hotspotSupportedChanged);
+
 public:
-    bool hotspotSupported() const { return m_hotspotSupported; };
+    bool hotspotSupported() const
+    {
+        return m_hotspotSupported;
+    };
 
 public Q_SLOTS:
     /**
@@ -85,7 +74,7 @@ public Q_SLOTS:
      * @param ssid the name of the network being displayed
      * @param securityType the authentication protocol used for this specific ssid
      */
-    QString wifiCode(const QString& connectionPath, const QString& ssid, /*NetworkManager::WirelessSecurityType*/ int securityType) const;
+    QString wifiCode(const QString &connectionPath, const QString &ssid, /*NetworkManager::WirelessSecurityType*/ int securityType) const;
 
     /**
      * Adds a new connection
@@ -112,7 +101,7 @@ public Q_SLOTS:
      * Removes given connection
      * @connection - d-bus path of the connection you want to edit
      */
-    void removeConnection(const QString & connection);
+    void removeConnection(const QString &connection);
     /**
      * Updates given connection
      * @connection - connection which should be updated
@@ -138,6 +127,7 @@ Q_SIGNALS:
     void hotspotCreated();
     void hotspotDisabled();
     void hotspotSupportedChanged(bool hotspotSupported);
+
 private:
     bool m_hotspotSupported;
     bool m_runningLiveImage;
@@ -150,7 +140,7 @@ private:
     QString m_tmpDevicePath;
     QString m_tmpSpecificPath;
     QMap<QString, bool> m_bluetoothAdapters;
-    QMap<QString, QTimer*> m_wirelessScanRetryTimer;
+    QMap<QString, QTimer *> m_wirelessScanRetryTimer;
 
     void enableBluetooth(bool enable);
     void scanRequestFailed(const QString &interface);
