@@ -5,9 +5,6 @@
 */
 
 #include "creatableconnectionsmodel.h"
-
-#include "configuration.h"
-
 #include <KLocalizedString>
 #include <KPluginMetaData>
 
@@ -37,9 +34,7 @@ CreatableConnectionItem::CreatableConnectionItem(QObject *parent)
 {
 }
 
-CreatableConnectionItem::~CreatableConnectionItem()
-{
-}
+CreatableConnectionItem::~CreatableConnectionItem() = default;
 NetworkManager::ConnectionSettings::ConnectionType CreatableConnectionItem::connectionType() const
 {
     return m_connectionType;
@@ -123,7 +118,19 @@ void CreatableConnectionItem::setVpnType(const QString &vpnType)
 CreatableConnectionsModel::CreatableConnectionsModel(QObject *parent)
     : QAbstractListModel(parent)
 {
-    CreatableConnectionItem *connectionItem;
+    populateModel();
+}
+
+void CreatableConnectionsModel::populateModel()
+{
+    beginResetModel();
+
+    if (!m_list.isEmpty()) {
+        qDeleteAll(m_list);
+        m_list.clear();
+    }
+
+    CreatableConnectionItem *connectionItem{nullptr};
     connectionItem = new CreatableConnectionItem(i18n("DSL"),
                                                  i18n("Hardware based connections"),
                                                  i18n("Some DSL description"),
@@ -181,47 +188,45 @@ CreatableConnectionsModel::CreatableConnectionsModel(QObject *parent)
                                                  true); // VpnType and SpecificType are empty
     m_list << connectionItem;
 
-    if (Configuration::self().manageVirtualConnections()) {
-        connectionItem = new CreatableConnectionItem(i18n("Bond"),
-                                                     i18n("Virtual connections"),
-                                                     i18n("Some bond description"),
-                                                     QStringLiteral("network-wired"),
-                                                     NetworkManager::ConnectionSettings::Bond,
-                                                     QString(),
-                                                     QString(),
-                                                     true); // VpnType and SpecificType are empty
-        m_list << connectionItem;
+    connectionItem = new CreatableConnectionItem(i18n("Bond"),
+                                                 i18n("Virtual connections"),
+                                                 i18n("Some bond description"),
+                                                 QStringLiteral("network-wired"),
+                                                 NetworkManager::ConnectionSettings::Bond,
+                                                 QString(),
+                                                 QString(),
+                                                 true); // VpnType and SpecificType are empty
+    m_list << connectionItem;
 
-        connectionItem = new CreatableConnectionItem(i18n("Bridge"),
-                                                     i18n("Virtual connections"),
-                                                     i18n("Some bond description"),
-                                                     QStringLiteral("network-wired"),
-                                                     NetworkManager::ConnectionSettings::Bridge,
-                                                     QString(),
-                                                     QString(),
-                                                     true); // VpnType and SpecificType are empty
-        m_list << connectionItem;
+    connectionItem = new CreatableConnectionItem(i18n("Bridge"),
+                                                 i18n("Virtual connections"),
+                                                 i18n("Some bond description"),
+                                                 QStringLiteral("network-wired"),
+                                                 NetworkManager::ConnectionSettings::Bridge,
+                                                 QString(),
+                                                 QString(),
+                                                 true); // VpnType and SpecificType are empty
+    m_list << connectionItem;
 
-        connectionItem = new CreatableConnectionItem(i18n("Team"),
-                                                     i18n("Virtual connections"),
-                                                     i18n("Some team description"),
-                                                     QStringLiteral("network-wired"),
-                                                     NetworkManager::ConnectionSettings::Team,
-                                                     QString(),
-                                                     QString(),
-                                                     true); // VpnType and SpecificType are empty
-        m_list << connectionItem;
+    connectionItem = new CreatableConnectionItem(i18n("Team"),
+                                                 i18n("Virtual connections"),
+                                                 i18n("Some team description"),
+                                                 QStringLiteral("network-wired"),
+                                                 NetworkManager::ConnectionSettings::Team,
+                                                 QString(),
+                                                 QString(),
+                                                 true); // VpnType and SpecificType are empty
+    m_list << connectionItem;
 
-        connectionItem = new CreatableConnectionItem(i18n("Vlan"),
-                                                     i18n("Virtual connections"),
-                                                     i18n("Some vlan description"),
-                                                     QStringLiteral("network-wired"),
-                                                     NetworkManager::ConnectionSettings::Vlan,
-                                                     QString(),
-                                                     QString(),
-                                                     true); // VpnType and SpecificType are empty
-        m_list << connectionItem;
-    }
+    connectionItem = new CreatableConnectionItem(i18n("Vlan"),
+                                                 i18n("Virtual connections"),
+                                                 i18n("Some vlan description"),
+                                                 QStringLiteral("network-wired"),
+                                                 NetworkManager::ConnectionSettings::Vlan,
+                                                 QString(),
+                                                 QString(),
+                                                 true); // VpnType and SpecificType are empty
+    m_list << connectionItem;
 
     QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"));
 
@@ -230,8 +235,8 @@ CreatableConnectionsModel::CreatableConnectionsModel(QObject *parent)
     });
 
     for (const auto &service : qAsConst(plugins)) {
-        const QString vpnType = service.value("X-NetworkManager-Services");
-        const QString vpnSubType = service.value("X-NetworkManager-Services-Subtype");
+        const QString vpnType = service.value(QStringLiteral("X-NetworkManager-Services"));
+        const QString vpnSubType = service.value(QStringLiteral("X-NetworkManager-Services-Subtype"));
         const QString vpnDescription = service.description();
 
         connectionItem = new CreatableConnectionItem(service.name(),
@@ -264,15 +269,14 @@ CreatableConnectionsModel::CreatableConnectionsModel(QObject *parent)
                                                  i18n("Import a saved configuration file"),
                                                  QStringLiteral("document-import"),
                                                  NetworkManager::ConnectionSettings::Vpn,
-                                                 QLatin1String("imported"),
-                                                 QLatin1String("imported"),
+                                                 QStringLiteral("imported"),
+                                                 QStringLiteral("imported"),
                                                  false);
     m_list << connectionItem;
+    endResetModel();
 }
 
-CreatableConnectionsModel::~CreatableConnectionsModel()
-{
-}
+CreatableConnectionsModel::~CreatableConnectionsModel() = default;
 
 QVariant CreatableConnectionsModel::data(const QModelIndex &index, int role) const
 {
@@ -303,7 +307,7 @@ QVariant CreatableConnectionsModel::data(const QModelIndex &index, int role) con
         }
     }
 
-    return QVariant();
+    return {};
 }
 
 QHash<int, QByteArray> CreatableConnectionsModel::roleNames() const
