@@ -41,7 +41,7 @@ private Q_SLOTS:
 
 private:
     void loadConfig(const NetworkManager::VpnSetting::Ptr &setting);
-    Ui::L2tpIpsecWidget *m_ui;
+    Ui::L2tpIpsecWidget *const m_ui;
     static IpsecDaemonType m_ipsecDaemonType;
 };
 
