@@ -15,8 +15,8 @@
 
 #include <KLocalizedString>
 
-#include "debug.h"
 #include "nm-openvpn-service.h"
+#include "plasma_nm_openvpn.h"
 
 class OpenVpnAuthWidgetPrivate
 {
@@ -59,8 +59,8 @@ void OpenVpnAuthWidget::readSecrets()
     if (!m_hints.isEmpty()) {
         QString passwordType;
         QString prompt;
-        for (const QString &hint : m_hints) {
-            const QString vpnMessage = QLatin1String("x-vpn-message:");
+        for (const QString &hint : qAsConst(m_hints)) {
+            const QString vpnMessage = QStringLiteral("x-vpn-message:");
             if (hint.startsWith(vpnMessage)) {
                 prompt = hint.right(hint.length() - vpnMessage.length());
             } else {
@@ -114,7 +114,7 @@ void OpenVpnAuthWidget::readSecrets()
     }
 
     for (int i = 0; i < d->layout->rowCount(); i++) {
-        PasswordField *le = qobject_cast<PasswordField *>(d->layout->itemAt(i, QFormLayout::FieldRole)->widget());
+        auto le = qobject_cast<PasswordField *>(d->layout->itemAt(i, QFormLayout::FieldRole)->widget());
         if (le && le->text().isEmpty()) {
             le->setFocus(Qt::OtherFocusReason);
             break;
@@ -129,7 +129,7 @@ QVariantMap OpenVpnAuthWidget::setting() const
     NMStringMap secrets;
     QVariantMap secretData;
     for (int i = 0; i < d->layout->rowCount(); i++) {
-        PasswordField *le = qobject_cast<PasswordField *>(d->layout->itemAt(i, QFormLayout::FieldRole)->widget());
+        auto le = qobject_cast<PasswordField *>(d->layout->itemAt(i, QFormLayout::FieldRole)->widget());
         if (le && !le->text().isEmpty()) {
             const QString key = le->property("nm_secrets_key").toString();
             secrets.insert(key, le->text());
@@ -144,9 +144,9 @@ void OpenVpnAuthWidget::addPasswordField(const QString &labelText, const QString
 {
     Q_D(const OpenVpnAuthWidget);
 
-    QLabel *label = new QLabel(this);
+    auto label = new QLabel(this);
     label->setText(labelText);
-    PasswordField *lineEdit = new PasswordField(this);
+    auto lineEdit = new PasswordField(this);
     lineEdit->setPasswordModeEnabled(passwordMode);
     lineEdit->setProperty("nm_secrets_key", secretKey);
     lineEdit->setText(password);
